<?php
/*
Plugin Name: XML Google Maps
Plugin URI: http://www.matusz.ch/blog/projekte/xml-google-maps-wordpress-plugin/
Feed URI: http://www.matusz.ch/blog/tags/xml-google-maps-wp-plugin/feed/
Description: Plugin to convert GPX, KML & KMZ Links to Google Maps.
Version: 0.8 Beta
Author: Patrick Matusz
Author URI: http://www.matusz.ch/blog/
*/

$wpdb->xmlgooglemapsdb = $table_prefix . 'xmlgooglemaps';

// Defining Options
define("key_xmlgm_uid", "xmlgm_uid", true);
define("xmlgm_uid_default", "(none)", true);
define("key_xmlgm_width", "xmlgm_width", true);
define("xmlgm_width_default", "664", true);
define("key_xmlgm_height", "xmlgm_height", true);
define("xmlgm_height_default", "400", true);
define("key_xmlgm_align", "xmlgm_align", true);
define("xmlgm_align_default", "left", true);
define("key_xmlgm_linecolor", "xmlgm_linecolor", true);
define("xmlgm_linecolor_default", "blue", true);
define("key_xmlgm_urldisplaymode", "xmlgm_urldisplaymode", true);
define("xmlgm_urldisplaymode_default", "title", true);
define("key_xmlgm_viewstyle", "xmlgm_viewstyle", true);
define("xmlgm_viewstyle_default", "G_MAP_TYPE", true);
define("key_xmlgm_linewidth", "xmlgm_linewidth", true);
define("xmlgm_linewidth_default", "5", true);
define("key_xmlgm_lineopacity", "xmlgm_lineopacity", true);
define("xmlgm_lineopacity_default", "50", true);
define("key_xmlgm_gpxview", "xmlgm_gpxview", true);
define("xmlgm_gpxview_default", "all", true);
define("key_xmlgm_panzoomcontrol", "xmlgm_panzoomcontrol", true);
define("xmlgm_panzoomcontrol_default", "large", true);
define("key_xmlgm_overviewmap", "xmlgm_overviewmap", true);
define("xmlgm_overviewmap_default", "hide", true);
define("key_xmlgm_scalecontrol", "xmlgm_scalecontrol", true);
define("xmlgm_scalecontrol_default", "hide", true);
define("key_xmlgm_maptypecontrol", "xmlgm_maptypecontrol", true);
define("xmlgm_maptypecontrol_default", "show", true);

add_option(key_xmlgm_uid, xmlgm_uid_default, 'Your Google Maps API Key');
add_option(key_xmlgm_width, xmlgm_width_default, 'Width of your Google Map');
add_option(key_xmlgm_height, xmlgm_height_default, 'Height of your Google Map');
add_option(key_xmlgm_align, xmlgm_align_default, 'Align of your Google Map');
add_option(key_xmlgm_linecolor, xmlgm_linecolor_default, 'Default Line Color of Tracks and Routes');
add_option(key_xmlgm_urldisplaymode, xmlgm_urldisplaymode_default, 'Default display mode for URL');
add_option(key_xmlgm_viewstyle, xmlgm_viewstyle_default, 'Default style for MAP');
add_option(key_xmlgm_linewidth, xmlgm_linewidth_default, 'Default Line Width of Tracks and Routes');
add_option(key_xmlgm_lineopacity, xmlgm_lineopacity_default, 'Default Line Opacity of Tracks and Routes');
add_option(key_xmlgm_gpxview, xmlgm_gpxview_default, 'Default GPX View Mode');
add_option(key_xmlgm_panzoomcontrol, xmlgm_panzoomcontrol_default, 'Pan/Zoom Control');
add_option(key_xmlgm_overviewmap, xmlgm_overviewmap_default, 'Overview Map Control');
add_option(key_xmlgm_scalecontrol, xmlgm_scalecontrol_default, 'Scale Control');
add_option(key_xmlgm_maptypecontrol, xmlgm_maptypecontrol_default, 'Map Type Control');

//Actions & Filters
add_filter('the_content', 'xmlgooglemaps_converter', 2);
add_filter('upload_mimes', 'xmlgooglemaps_mimes');
add_action('admin_menu', 'add_xmlgm_option_page');

//Add Option Page
function add_xmlgm_option_page() {
	global $wpdb;
	add_options_page('XML Google Maps Options', 'XML Google Maps', 8, basename(__FILE__), 'xmlgm_options_page');
}

function xmlgooglemaps_converter($content) {	
	global $wpdb;
	
	require_once('xmlgooglemaps_helper.php');	
	
	dbinstall();
		
	//GPX
	$content = xmlgooglemaps_converter_gpx($content);
	
	//KMX	
	$content = xmlgooglemaps_converter_kmx($content);
	
	// Google Maps Meine Karten: http://maps.google.com/maps/ms?ie=UTF8&hl=de&msa=0&output=nl&msid=102758581694521177745.00000111d56d20b14f816
	$content = xmlgooglemaps_converter_GoogleMaps($content);

	//XML Google Maps Parts
	$content = xmlgooglemaps_converter_myxmlgm($content);
	
	return $content;	
}

function xmlgooglemaps_mimes($mimes) {
	$mime_types = array ('gpx' => 'application/gpx', 'kml' => 'application/vnd.google-earth.kml+xml', 'kmz' => 'application/vnd.google-earth.kmz+xml');
    return array_merge($mimes,$mime_types);
}

function dbinstall() {
	global $wpdb;
	// Create Post Ratings Table
	if (!gmxml_tableexists($wpdb->xmlgooglemapsdb)) {	
		$create_sql = "CREATE TABLE $wpdb->xmlgooglemapsdb (".
				"xml_id INT(11) NOT NULL auto_increment,".
				"xml_path TEXT NOT NULL ,".
				"xml_path_resolved TEXT NOT NULL ,".
				"PRIMARY KEY (xml_id))";
		$wpdb->query($create_sql);
	}
	if (!gmxml_columnexists($wpdb->xmlgooglemapsdb,"xml_varstring")) {
		$column_sql = "ALTER TABLE $wpdb->xmlgooglemapsdb ADD COLUMN xml_varstring TEXT NOT NULL;";
		$wpdb->query($column_sql);
	}
}

function xmlgooglemaps_converter_GoogleMaps($content) {
	preg_match_all('/\<a(.*?)href="(http:\/\/maps\.google\.com\/maps\/ms[a-zA-Z0-9\/:\-\._?&=;]*?)"(.*?)\>(.*?)\<\/a\>/i', $content, $found);

	for ($i=0; $i< count($found[0]);$i++) {
		$file = $found[2][$i];
		$file_resolved = $file;
		
		$displayurl = $found[0][$i];
		$urlstring = $found[4][$i];
		
		$iurlstring = stripos($urlstring,"[");
		if ($iurlstring !== false) {
			$jurlstring = stripos($urlstring,"]",$iurlstring);
			$iurlstring += 1;
			$varstring = substr($urlstring, $iurlstring, $jurlstring-$iurlstring);
		} else {
			$varstring = "";
		}
		
		$params = new xml_gm_params();
		$params->setParams($varstring);		
		$displayurl = getDisplayURL($params->urlDisplayMode, $displayurl);		
		
		$mygooglemapid = getid($file, $file_resolved, $varstring);
		
		$content = str_replace($found[0][$i],'<div style="text-align: '.$params->align.';"><iframe src="'.get_option('siteurl').'/wp-content/plugins/xml-google-maps/xmlgooglemaps_show.php?mygooglemapid='.$mygooglemapid.'" style="border: 0px; width: '.$params->width.'px; height: '.$params->height.'px;" name="Google My Map"></iframe></div>'.$displayurl,$content);
	}	
	return $content;
}

function xmlgooglemaps_converter_kmx($content) {
	preg_match_all('/\<a(.*?)href="([a-zA-Z0-9\/:\-\._]*?.km[lz])"(.*?)\>(.*?)\<\/a\>/i', $content, $found);
		
	for ($i=0; $i< count($found[0]);$i++) {
		$file = $found[2][$i];
		
		$server_url = $_SERVER["HTTP_HOST"];
		$server_path = $_SERVER["DOCUMENT_ROOT"];		
		$index = stripos($file,"://");
		$server_url = substr($file,0,$index+3).$server_url;
		
		$file_resolved = $file;

		if (stripos($file,$server_url)==0) {
			$file_resolved = str_replace($server_url,$server_path,$file);
		}

		$displayurl = $found[0][$i];
		$urlstring = $found[4][$i];
		$iurlstring = stripos($urlstring,"[");
		if ($iurlstring !== false) {
			$jurlstring = stripos($urlstring,"]",$iurlstring);
			$iurlstring += 1;
			$varstring = substr($urlstring, $iurlstring, $jurlstring-$iurlstring);
		} else {
			$varstring = "";
		}
		
		$params = new xml_gm_params();
		$params->setParams($varstring);		
		$displayurl = getDisplayURL($params->urlDisplayMode, $displayurl);				
				
		$kmlid = getid($file, $file_resolved, $varstring);
		
		$content = str_replace($found[0][$i],'<div style="text-align: '.$params->align.';"><iframe src="'.get_option('siteurl').'/wp-content/plugins/xml-google-maps/xmlgooglemaps_show.php?kmlid='.$kmlid.'" style="border: 0px; width: '.$params->width.'px; height: '.$params->height.'px;" name="Google KML Maps"></iframe></div>'.$displayurl,$content);
	}
	return $content;
}

function xmlgooglemaps_converter_myxmlgm($content) {
	preg_match_all('/\[xmlgm (.*?)\]/i', $content, $found);
	for ($i=0; $i< count($found[0]);$i++) {
		$varstring = str_replace("[xmlgm ","", $found[0][$i]);
		$varstring = str_replace("]","", $varstring);
				
		$params = new xml_gm_params();
		$params->setParams($varstring);			
		
		$myid = getid("", "", $varstring);
		
		$content = str_replace($found[0][$i],'<div style="text-align: '.$params->align.';"><iframe src="'.get_option('siteurl').'/wp-content/plugins/xml-google-maps/xmlgooglemaps_show.php?myid='.$myid.'" style="border: 0px; width: '.$params->width.'px; height: '.$params->height.'px;" name="My XML Google Maps"></iframe></div>',$content);
	}
	
	return $content;
}


function xmlgooglemaps_converter_gpx($content) {
	preg_match_all('/\<a(.*?)href="([a-zA-Z0-9\/:\-\._]*?.gpx)"(.*?)\>(.*?)\<\/a\>/i', $content, $found);
	for ($i=0; $i< count($found[0]);$i++) {
		$file = $found[2][$i];
		
		$server_url = $_SERVER["HTTP_HOST"];
		$server_path = $_SERVER["DOCUMENT_ROOT"];		
		$index = stripos($file,"://");
		$server_url = substr($file,0,$index+3).$server_url;
		
		$file_resolved = $file;

		if (stripos($file,$server_url)==0) {
			$file_resolved = str_replace($server_url,$server_path,$file);
		}
		
		$urlstring = $found[4][$i];
		$iurlstring = stripos($urlstring,"[");
		$displayurl = $found[0][$i];
		if ($iurlstring !== false) {
			$jurlstring = stripos($urlstring,"]",$iurlstring);
			$iurlstring += 1;
			$varstring = substr($urlstring, $iurlstring, $jurlstring-$iurlstring);			
		} else {
			$varstring = "";
		}		
		
		$params = new xml_gm_params();
		$params->setParams($varstring);		
		$displayurl = getDisplayURL($params->urlDisplayMode, $displayurl);		
		
		$gpxid = getid($file, $file_resolved, $varstring);
		
		$content = str_replace($found[0][$i],'<div style="text-align: '.$params->align.';"><iframe src="'.get_option('siteurl').'/wp-content/plugins/xml-google-maps/xmlgooglemaps_show.php?gpxid='.$gpxid.'" style="border: 0px; width: '.$params->width.'px; height: '.$params->height.'px;" name="Google Gpx Maps"></iframe></div>'.$displayurl,$content);
	}
	
	return $content;
}

function gmxml_tableexists($tablename) {
	global $wpdb;
	foreach ($wpdb->get_col("SHOW TABLES",0) as $table ) {
		if ($table == $tablename) {
			return true;
		}
	}
	return false;
}

function gmxml_columnexists($tablename, $columnname) {
	global $wpdb;
	foreach ($wpdb->get_col("DESC $tablename", 0) as $column ) {
		if ($column == $columnname) {
			return true;
		}
	}
	return false;
}

function getid($path, $resolvedpath, $varstring) {
	global $wpdb;
	// Check IP From IP Logging Database
	$ret = $wpdb->get_var("SELECT xml_id FROM $wpdb->xmlgooglemapsdb WHERE xml_path = '$path' AND xml_path_resolved = '$resolvedpath' AND xml_varstring = '$varstring'");
	if ($ret == 0) {
		$wpdb->query("INSERT INTO $wpdb->xmlgooglemapsdb (xml_path, xml_path_resolved, xml_varstring) VALUES ('$path','$resolvedpath','$varstring')");
		$ret = getid($path, $resolvedpath, $varstring);
	}
	return intval($ret);	
}

//Optiona Page
function xmlgm_options_page() {
	// If we are a postback, store the options
 	if (isset($_POST['info_update'])) {
		check_admin_referer();
		
		// Google Maps API
		$xmlgm_uid = $_POST[key_xmlgm_uid];
		if ($xmlgm_uid == '')
			$xmlgm_uid = xmlgm_uid_default;
		update_option(key_xmlgm_uid, $xmlgm_uid);
		
		//Width
		$xmlgm_width = intval($_POST[key_xmlgm_width]);
		if ($xmlgm_width == 0)
			$xmlgm_width = xmlgm_width_default;
		update_option(key_xmlgm_width, $xmlgm_width);
		
		//Height
		$xmlgm_height = intval($_POST[key_xmlgm_height]);
		if ($xmlgm_height == 0)
			$xmlgm_height = xmlgm_height_default;
		update_option(key_xmlgm_height, $xmlgm_height);

		// IFrame Align
		$xmlgm_align = $_POST[key_xmlgm_align];
		if ($xmlgm_align == '')
			$xmlgm_align = xmlgm_align_default;
		update_option(key_xmlgm_align, $xmlgm_align);		

		// Line Color
		$xmlgm_linecolor = $_POST[key_xmlgm_linecolor];
		if ($xmlgm_linecolor == '')
			$xmlgm_linecolor = xmlgm_linecolor_default;
		update_option(key_xmlgm_linecolor, $xmlgm_linecolor);
		
		// URL Display Mode
		$xmlgm_urldisplaymode = $_POST[key_xmlgm_urldisplaymode];
		if ($xmlgm_urldisplaymode == '')
			$xmlgm_urldisplaymode = xmlgm_urldisplaymode_default;
		update_option(key_xmlgm_urldisplaymode, $xmlgm_urldisplaymode);

		//Map View Style
		$xmlgm_viewstyle = $_POST[key_xmlgm_viewstyle];
		if ($xmlgm_viewstyle == '')
			$xmlgm_viewstyle = xmlgm_viewstyle_default;
		update_option(key_xmlgm_viewstyle, $xmlgm_viewstyle);

		//Line Width
		$xmlgm_linewidth = intval($_POST[key_xmlgm_linewidth]);
		if ($xmlgm_linewidth == 0)
			$xmlgm_linewidth = xmlgm_linewidth_default;
		update_option(key_xmlgm_linewidth, $xmlgm_linewidth);		
		
		//Line Opacity
		$xmlgm_lineopacity = intval($_POST[key_xmlgm_lineopacity]);
		if (($xmlgm_lineopacity < 0) || ($xmlgm_lineopacity > 100)) 
			$xmlgm_lineopacity = xmlgm_lineopacity_default;
		update_option(key_xmlgm_lineopacity, $xmlgm_lineopacity);

		//GPX View Style
		$xmlgm_gpxview = $_POST[key_xmlgm_gpxview];
		if ($xmlgm_gpxview == '')
			$xmlgm_gpxview = xmlgm_gpxview_default;
		update_option(key_xmlgm_gpxview, $xmlgm_gpxview);

		//Pan/Zoom Control
		$xmlgm_panzoomcontrol = $_POST[key_xmlgm_panzoomcontrol];
		if ($xmlgm_panzoomcontrol == '')
			$xmlgm_panzoomcontrol = xmlgm_panzoomcontrol_default;
		update_option(key_xmlgm_panzoomcontrol, $xmlgm_panzoomcontrol);

		//Overview Map Control
		$xmlgm_overviewmap = $_POST[key_xmlgm_overviewmap];
		if ($xmlgm_overviewmap == '')
			$xmlgm_overviewmap = xmlgm_overviewmap_default;
		update_option(key_xmlgm_overviewmap, $xmlgm_overviewmap);
		
		//Scale Control
		$xmlgm_scalecontrol = $_POST[key_xmlgm_scalecontrol];
		if ($xmlgm_scalecontrol == '')
			$xmlgm_scalecontrol = xmlgm_scalecontrol_default;
		update_option(key_xmlgm_scalecontrol, $xmlgm_scalecontrol);

		//Map Type Control
		$xmlgm_maptypecontrol = $_POST[key_xmlgm_maptypecontrol];
		if ($xmlgm_maptypecontrol == '')
			$xmlgm_maptypecontrol = xmlgm_maptypecontrol_default;
		update_option(key_xmlgm_maptypecontrol, $xmlgm_maptypecontrol);
		
		// Give an updated message
		echo "<div class='updated'><p><strong>XML Google Maps options updated</strong></p></div>";
	}

	// Output the options page
	?>

		<form method="post" action="options-general.php?page=xmlgooglemaps.php">
		<div class="wrap">
			<h2>XML Google Maps Options</h2>
			<fieldset class='options'>
				<legend>Basic Options</legend>
				<table class="editform" cellspacing="2" cellpadding="5" width="100%">
					<tr>
						<th valign="top" style="padding-top: 10px;" width="30%">
							<label for="<?php echo key_xmlgm_uid; ?>">Your Google Maps API Key:</label>
						</th>
						<td width="70%">
							<?php
							echo "<input type='text' size='50' ";
							echo "name='".key_xmlgm_uid."' ";
							echo "id='".key_xmlgm_uid."' ";
							echo "value='".get_option(key_xmlgm_uid)."' />\n";
							?>
							<p style="margin: 5px 10px;">Enter your Google Maps API Key in this box</p>
						</td>
					</tr>
					<tr>
						<th valign="top" style="padding-top: 10px;" width="30%">
							<label for="<?php echo key_xmlgm_width; ?>">Width:</label>
						</th>
						<td width="70%">
							<?php
							echo "<input type='text' size='50' ";
							echo "name='".key_xmlgm_width."' ";
							echo "id='".key_xmlgm_width."' ";
							echo "value='".get_option(key_xmlgm_width)."' />\n";
							?>
							<p style="margin: 5px 10px;">Enter the width of yout Google Maps (only numeric value allowed)</p>
						</td>
					</tr>
					<tr>
						<th valign="top" style="padding-top: 10px;" width="30%">
							<label for="<?php echo key_xmlgm_height; ?>">Height:</label>
						</th>
						<td width="70%">
							<?php
							echo "<input type='text' size='50' ";
							echo "name='".key_xmlgm_height."' ";
							echo "id='".key_xmlgm_height."' ";
							echo "value='".get_option(key_xmlgm_height)."' />\n";
							?>
							<p style="margin: 5px 10px;">Enter the height of yout Google Maps (only numeric values allowed)</p>
						</td>
					</tr>
					<tr>
						<th valign="top" style="padding-top: 10px;"  width="30%">
							<label for="<?php echo key_xmlgm_align; ?>">IFrame align:</label>
						</th>
						<td  width="70%">
							<?php
							echo "<select ";
							echo "name='".key_xmlgm_align."' ";
							echo "id='".key_xmlgm_align."'>";
							switch (get_option(key_xmlgm_align)) 
							{
								case "right": $selright = "selected='selected'"; break;
								case "center": $selcenter = "selected='selected'"; break;
								default: $selleft = "selected='selected'"; break;
							}
							echo "<option value='left' $selleft>Left (left)</option>";
							echo "<option value='center' $selcenter>Center (center)</option>";
							echo "<option value='right' $selright>Right (right)</option>";
							echo "</select>\n";
							?>
							<p style="margin: 5px 10px;">Aligns the iframe</p>
						</td>
					</tr>					
				</table>
			</fieldset>								
			<fieldset class='options'>
				<legend>Default Values</legend>
				<table class="editform" cellspacing="2" cellpadding="5" width="100%">																	
					<tr>
						<th valign="top" style="padding-top: 10px;"  width="30%">
							<label for="<?php echo key_xmlgm_urldisplaymode; ?>">URL Display Mode:</label>
						</th>
						<td  width="70%">
							<?php
							echo "<select ";
							echo "name='".key_xmlgm_urldisplaymode."' ";
							echo "id='".key_xmlgm_urldisplaymode."'>";
							switch (get_option(key_xmlgm_urldisplaymode)) 
							{
								case "none": $selnoneud = "selected='selected'"; break;
								case "showvars": $selvars = "selected='selected'"; break;
								default: $seldefault = "selected='selected'"; break;
							}
							echo "<option value='title' $seldefault>Map, URL Title without Parameters (title)</option>";
							echo "<option value='none' $selnoneud>Map only (none)</option>";
							echo "<option value='showvars' $selvars>Map, URL Title and Parameters (showvars)</option>";
							echo "</select>\n";
							?>
							<p style="margin: 5px 10px;">Display mode of the URL</p>
						</td>
					</tr>									
					<tr>
						<th valign="top" style="padding-top: 10px;"  width="30%">
							<label for="<?php echo key_xmlgm_viewstyle; ?>">Map View Style:</label>
						</th>
						<td  width="70%">
							<?php
							echo "<select ";
							echo "name='".key_xmlgm_viewstyle."' ";
							echo "id='".key_xmlgm_viewstyle."'>";
							switch (get_option(key_xmlgm_viewstyle)) 
							{
								case "G_SATELLITE_TYPE": $selsat = "selected='selected'"; break;
								case "G_HYBRID_TYPE": $selhyb = "selected='selected'"; break;
								default: $selmap = "selected='selected'"; break;
							}
							echo "<option value='G_HYBRID_TYPE' $selhyb>Hybrid (G_HYBRID_TYPE)</option>";
							echo "<option value='G_SATELLITE_TYPE' $selsat>Satellite (G_SATELLITE_TYPE)</option>";
							echo "<option value='G_MAP_TYPE' $selmap>Map (G_MAP_TYPE)</option>";
							echo "</select>\n";
							?>
							<p style="margin: 5px 10px;">Default Map Display Style</p>
						</td>
					</tr>
					<tr>
						<th valign="top" style="padding-top: 10px;"  width="30%">
							<label for="<?php echo key_xmlgm_panzoomcontrol; ?>">Pan/Zoom Control:</label>
						</th>
						<td  width="70%">
							<?php
							echo "<select ";
							echo "name='".key_xmlgm_panzoomcontrol."' ";
							echo "id='".key_xmlgm_panzoomcontrol."'>";
							switch (get_option(key_xmlgm_panzoomcontrol)) 
							{
								case "hide": $selnonepz = "selected='selected'"; break;
								case "small": $selsmall = "selected='selected'"; break;
								case "zoom": $selzoom = "selected='selected'"; break;
								default: $sellarge = "selected='selected'"; break;
							}
							echo "<option value='hide' $selnonepz>Invisible (hide)</option>";
							echo "<option value='large' $sellarge>Large (large)</option>";
							echo "<option value='small' $selsmall>Small (small)</option>";
							echo "<option value='zoom' $selzoom>Zoom only (zoom)</option>";
							echo "</select>\n";
							?>
							<p style="margin: 5px 10px;">Default Pan/Zoom Control</p>
						</td>
					</tr>									
					<tr>
						<th valign="top" style="padding-top: 10px;"  width="30%">
							<label for="<?php echo key_xmlgm_overviewmap; ?>">Overview Map Control:</label>
						</th>
						<td  width="70%">
							<?php
							echo "<select ";
							echo "name='".key_xmlgm_overviewmap."' ";
							echo "id='".key_xmlgm_overviewmap."'>";
							switch (get_option(key_xmlgm_overviewmap)) 
							{
								case "show": $selshowom = "selected='selected'"; break;
								default: $selhideom = "selected='selected'"; break;
							}
							echo "<option value='hide' $selhideom>Invisible (hide)</option>";
							echo "<option value='show' $selshowom>Visible (show)</option>";
							echo "</select>\n";
							?>
							<p style="margin: 5px 10px;">Default Overview Map Control</p>
						</td>
					</tr>									
					<tr>
						<th valign="top" style="padding-top: 10px;"  width="30%">
							<label for="<?php echo key_xmlgm_scalecontrol; ?>">Scale Control:</label>
						</th>
						<td  width="70%">
							<?php
							echo "<select ";
							echo "name='".key_xmlgm_scalecontrol."' ";
							echo "id='".key_xmlgm_scalecontrol."'>";
							switch (get_option(key_xmlgm_scalecontrol)) 
							{
								case "show": $selshowsc = "selected='selected'"; break;
								default: $selhidesc = "selected='selected'"; break;
							}
							echo "<option value='hide' $selhidesc>Invisible (hide)</option>";
							echo "<option value='show' $selshowsc>Visible (show)</option>";
							echo "</select>\n";
							?>
							<p style="margin: 5px 10px;">Default Scale Control</p>
						</td>
					</tr>															
					<tr>
						<th valign="top" style="padding-top: 10px;"  width="30%">
							<label for="<?php echo key_xmlgm_maptypecontrol; ?>">Map Type Control:</label>
						</th>
						<td  width="70%">
							<?php
							echo "<select ";
							echo "name='".key_xmlgm_maptypecontrol."' ";
							echo "id='".key_xmlgm_maptypecontrol."'>";
							switch (get_option(key_xmlgm_maptypecontrol)) 
							{
								case "hide": $selhidemtc = "selected='selected'"; break;
								default: $selshowmtc = "selected='selected'"; break;
							}
							echo "<option value='hide' $selhidemtc>Invisible (hide)</option>";
							echo "<option value='show' $selshowmtc>Visible (show)</option>";
							echo "</select>\n";
							?>
							<p style="margin: 5px 10px;">Default Map Type Control</p>
						</td>
					</tr>															
				</table>
			</fieldset>	
			<fieldset class='options'>
				<legend>GPX Default Values</legend>
				<table class="editform" cellspacing="2" cellpadding="5" width="100%">									
					<tr>
						<th valign="top" style="padding-top: 10px;"  width="30%">
							<label for="<?php echo key_xmlgm_linecolor; ?>">Line Color:</label>
						</th>
						<td  width="70%">
							<?php
							echo "<input type='text' size='50' ";
							echo "name='".key_xmlgm_linecolor."' ";
							echo "id='".key_xmlgm_linecolor."' ";
							echo "value='".get_option(key_xmlgm_linecolor)."' />\n";
							?>
							<p style="margin: 5px 10px;">Enter the default line color of any Track or Route</p>
						</td>
					</tr>
					<tr>
						<th valign="top" style="padding-top: 10px;" width="30%">
							<label for="<?php echo key_xmlgm_linewidth; ?>">Line Width:</label>
						</th>
						<td width="70%">
							<?php
							echo "<input type='text' size='50' ";
							echo "name='".key_xmlgm_linewidth."' ";
							echo "id='".key_xmlgm_linewidth."' ";
							echo "value='".get_option(key_xmlgm_linewidth)."' />\n";
							?>
							<p style="margin: 5px 10px;">Enter the default line width of any Track or Route</p>
						</td>
					</tr>
					<tr>
						<th valign="top" style="padding-top: 10px;" width="30%">
							<label for="<?php echo key_xmlgm_lineopacity; ?>">Line Opacity:</label>
						</th>
						<td width="70%">
							<?php
							echo "<input type='text' size='50' ";
							echo "name='".key_xmlgm_lineopacity."' ";
							echo "id='".key_xmlgm_lineopacity."' ";
							echo "value='".get_option(key_xmlgm_lineopacity)."' />\n";
							?>
							<p style="margin: 5px 10px;">Enter the default line opacity (1-100) of any Track or Route</p>
						</td>
					</tr>	
					<tr>
						<th valign="top" style="padding-top: 10px;"  width="30%">
							<label for="<?php echo key_xmlgm_gpxview; ?>">GPX View Style:</label>
						</th>
						<td  width="70%">
							<?php
							echo "<select ";
							echo "name='".key_xmlgm_gpxview."' ";
							echo "id='".key_xmlgm_gpxview."'>";
							switch (get_option(key_xmlgm_gpxview)) 
							{
								case "wpt": $selwpt = "selected='selected'"; break;
								case "rte": $selrte = "selected='selected'"; break;
								case "trk": $seltrk = "selected='selected'"; break;
								default: $selall = "selected='selected'"; break;
							}
							echo "<option value='all' $selall>Everything (all)</option>";
							echo "<option value='wpt' $selwpt>Waypoints (wpt)</option>";
							echo "<option value='rte' $selrte>Routes (rte)</option>";
							echo "<option value='trk' $seltrk>Tracks (trk)</option>";
							echo "</select>\n";
							?>
							<p style="margin: 5px 10px;">Shows only the selected part of the GPX File.</p>
						</td>
					</tr>									
																		
				</table>
			</fieldset>						
			<p class="submit">
				<input type='submit' name='info_update' value='Update Options' />
			</p>
		</div>
		</form>
<?php
}

function getDisplayURL($urldisplaymode, $displayurl) {
	switch ($urldisplaymode) {
		case "none":
			$displayurl = "";
			break;
		case "showvars":
			$displayurl = $displayurl;
			break;
		default:
			$displayurl = str_replace("[".$varstring."]","",$displayurl);
			break;			
	}
	return $displayurl;
}

// Not exististing Functions
if(!function_exists("stripos")) 
{
  function stripos($str, $needle) 
  {
   return strpos(strtolower($str),strtolower($needle));
  }
}

?>