<?php 

class googleMapAPI_PMPro {
	 
	var $api_key = "";
	var $map_id = "";
	var $width = "500px";
	var $height = "500px";
	var $map_type = "G_MAP_TYPE";
	var $markers = array();
	var $polylines = array();
	var $max_lon = -1000000;
	var $min_lon = 1000000;
	var $max_lat = -1000000;
	var $min_lat = 1000000;
	var $center_lat = 46.77429;
	var $center_lon = 7.57164;
	var $start_filter = 1;
	var $kml_url = "";
	var $panzoomcontrol = "GLargeMapControl";
	var $maptypecontrol = "GMapTypeControl";
	var $overviewmap = "";
	var $scalecontrol = "";
	
		
	function googleMapAPI_PMPro($api_key, $map_type="map") {
		$this->api_key = $api_key;
		
		$this->map_id = "map".md5(uniqid(rand())); 
		$this->setMapType($map_type);
	}
	
	function setPanZoomControl($value){
		switch ($value) {
			case "hide":
				$this->panzoomcontrol = "";
				break;
			case "small":
				$this->panzoomcontrol = "GSmallMapControl";
				break;
			case "zoom":
				$this->panzoomcontrol = "GSmallZoomControl";
				break;
			default:
				$this->panzoomcontrol = "GLargeMapControl";
				break;				
		}
	}
	
	function setOverviewMap($value) {
		switch ($value) {
			case "show":
				$this->overviewmap = "GOverviewMapControl";
				break;
			default:
				$this->overviewmap = "";
				break;				
		}		
	}
	
	function setScaleControl($value) {
		switch ($value) {
			case "show":
				$this->scalecontrol = "GScaleControl";
				break;
			default:
				$this->scalecontrol = "";
				break;				
		}		
	}

	function setMapTypeControl($value) {
		switch ($value) {
			case "hide":
				$this->maptypecontrol = "";
				break;
			default:
				$this->maptypecontrol = "GMapTypeControl";
				break;				
		}		
	}
	
	function setWidth($width) {
		if (!preg_match('!^(\d+)(.*)$!', $width, $_match)) {
			return false;
		}

		$_width = $_match[1];
		$_type = $_match[2];
		if ($_type == '%') {
			$this->width = $_width . '%';
		}
		else {
			$this->width = $_width . 'px';
		}

		return true;
	}
	
	function setStartFilter($filter) {
		if (is_numeric($filter)){
			if ($filter > 0) {
				$this->start_filter=$filter;
			} else {
				return false;
			}
		} else {
			return false;
		}
	}

	function setHeight($height) {
		if (!preg_match('!^(\d+)(.*)$!', $height,$_match)) {
			return false;
		}

		$_height = $_match[1];
		$_type = $_match[2];
		if ($_type == '%') {
			$this->height = $_height . '%';
		}
		else {
			$this->height = $_height . 'px';
		}

		return true;
	}
	
	function setSize($width, $height) {
		$this->setWidth($width);
		$this->setHeight($height);
	}
	
	function setMapType($type) {
		switch ($type) {
			case 'G_HYBRID_TYPE':
			case 'hybrid':
				$this->map_type = 'G_HYBRID_TYPE';
				break;
			case 'G_SATELLITE_TYPE':
			case 'satellite':
				$this->map_type = 'G_SATELLITE_TYPE';
				break;
			case 'G_MAP_TYPE':
			case 'map':
			default:
				$this->map_type = 'G_MAP_TYPE';
				break;
		}
	}
	
	function clear() {
		$this->markers = array();
		$this->polylines = array();
		$this->max_lon = -1000000;
		$this->min_lon = 1000000;
		$this->max_lat = -1000000;
		$this->min_lat = 1000000;
		$this->center_lat = 46.77429;
		$this->center_lon = 7.57164;
	}
	
	function addMarker($lat, $lon, $html = '', $iconImage = '', $iconShadowImage = '') {
		$marker['lon'] = $lon;
		$marker['lat'] = $lat;
		$marker['html'] = strlen($html) > 0 ? $html : $title;
		if ($iconImage) {
			if (!($_image_info = @getimagesize($iconImage))) {
				die('GoogleMapAPI:createMarkerIcon: Error reading image: ' . $iconImage);
			}
			if ($iconShadowImage) {
				if (!($_shadow_info = @getimagesize($iconShadowImage))) {
					die('GoogleMapAPI:createMarkerIcon: Error reading image: ' . $iconShadowImage);
				}
			}
			$iconAnchorX = (int) ($_image_info[0] / 2);
			$iconAnchorY = (int) ($_image_info[1] / 2);
			$infoWindowAnchorX = (int) ($_image_info[0] / 2);
			$infoWindowAnchorY = (int) ($_image_info[1] / 2);
			$icon_info = array(
								'image' => $iconImage,
								'iconWidth' => $_image_info[0],
								'iconHeight' => $_image_info[1],
								'iconAnchorX' => $iconAnchorX,
								'iconAnchorY' => $iconAnchorY,
								'infoWindowAnchorX' => $infoWindowAnchorX,
								'infoWindowAnchorY' => $infoWindowAnchorY
							);
			if ($iconShadowImage) {
				$icon_info = array_merge($icon_info, array(
															'shadow' => $iconShadowImage,
															'shadowWidth' => $_shadow_info[0],
															'shadowHeight' => $_shadow_info[1])
															);
			}
			$marker['icon'] = $icon_info;
		}
		$this->markers[] = $marker;
		$this->adjustCenterCoords($marker['lon'], $marker['lat']);
		return count($this->markers) - 1;
	}
	
	function addPolyline($color = '', $weight = 0, $opacity = 0) {
		$polyline["color"] = $color;
		$polyline["weight"] = $weight;
		$polyline["opacity"] = $opacity;
		$this->polylines[] = $polyline;
		return count($this->polylines) - 1;
	}
	
	function addPolylinePoint($polyline,$lat,$lon) 
	{
		$pt["lat"] = $lat;
		$pt["lon"] = $lon;
		$this->polylines[$polyline]["points"][] = $pt;
		$this->adjustCenterCoords($pt['lon'], $pt['lat']);
		return count($this->polylines[$polyline]["points"]) - 1;
	}
	
	function adjustCenterCoords($lon, $lat) {
		if (strlen((string)$lon) == 0 || strlen((string)$lat) == 0) {
			return false;
		}
		$this->max_lon = max($lon, $this->max_lon);
		$this->min_lon = min($lon, $this->min_lon);
		$this->max_lat = max($lat, $this->max_lat);
		$this->min_lat = min($lat, $this->min_lat);
		$this->center_lon = ($this->min_lon + $this->max_lon) / 2;
		$this->center_lat = ($this->min_lat + $this->max_lat) / 2;
		return true;
	}	
	
	function clearCenterCoords() {
		$this->max_lon = -1000000;
		$this->min_lon = 1000000;
		$this->max_lat = -1000000;
		$this->min_lat = 1000000;
		$this->center_lat = 46.77429;
		$this->center_lon = 7.57164;		
	}

	
	function getHeaderScript() {
		$ret .= $this->addLine('<script src="http://maps.google.com/maps?file=api&amp;v=2&amp;key=%s" type="text/javascript"></script>');
		return sprintf($ret, $this->api_key);
	}
		
	function setKML($url) {
		$this->kml_url = $url;
	}
	
	function getKMLContentElementOnly($url) {
		$mapname = $this->map_id;
		$kmlname = $this->map_id."geoXml";
		//Div
		$ret .= $this->addLine(sprintf('<div id="%s" style="width: %s; height: %s;"></div>',$this->map_id, $this->width, $this->height));
		$ret .= $this->addLine('<script type="text/javascript">');
		$ret .= $this->addLine('<!--',1);	
		//Initializing
		$ret .= $this->addLine(sprintf('var %s = null;',$mapname),2);		
		$ret .= $this->addLine(sprintf('var %s = null;',$kmlname),2);	

		//Workaraound for Showing other MapTypes than MAP
		$ret .= $this->addLine(sprintf('var smt_%s = function() {', $this->map_id),2);
		$ret .= $this->addLine(sprintf('%s.setMapType(%s);',$mapname,$this->map_type),3);
		$ret .= $this->addLine('}',2);
		
		//Callback after GeoLoading
		$ret .= $this->addLine(sprintf('var cb_geo_%s = function() {', $this->map_id),2);		
		if ($this->max_lon > -1000000) {							
			$ret .= $this->addLine(sprintf('var zoom = %s.getBoundsZoomLevel(new GLatLngBounds(new GLatLng(%s,%s),new GLatLng(%s,%s)));',$mapname,$this->min_lat,$this->min_lon,$this->max_lat,$this->max_lon),3);			
			$ret .= $this->addLine(sprintf('%s.setCenter(new GLatLng(%s,%s), zoom);',$mapname, $this->center_lat,$this->center_lon),3);			
		} else {	
			$ret .= $this->addLine(sprintf('%s.gotoDefaultViewport(%s);',$kmlname,$mapname),3);			
		}	
		if (strlen($this->panzoomcontrol)>0) {
		 $ret .= $this->addLine(sprintf('%s.addControl(new %s());',$mapname,$this->panzoomcontrol),3);
		}
		if (strlen($this->overviewmap)>0) {
		 $ret .= $this->addLine(sprintf('%s.addControl(new %s());',$mapname,$this->overviewmap),3);
		}		
		if (strlen($this->scalecontrol)>0) {
		 $ret .= $this->addLine(sprintf('%s.addControl(new %s());',$mapname,$this->scalecontrol),3);
		}		
		if (strlen($this->maptypecontrol)>0) {
		 $ret .= $this->addLine(sprintf('%s.addControl(new %s());',$mapname,$this->maptypecontrol),3);
		}														
		$ret .= $this->addLine(sprintf('%s.addOverlay(%s);', $mapname, $kmlname),3);
		$ret .= $this->addLine(sprintf('setTimeout(smt_%s, 100);', $mapname, $this->map_id),3);
		$ret .= $this->addLine('}',2);
		
		//Loading
		$url = str_replace("&amp;","&",$url);		
		$ret .= $this->addLine(sprintf('function load_%s() {', $this->map_id),2);
		$ret .= $this->addLine(sprintf('%s = new GMap2(document.getElementById("%s"));',$mapname,$this->map_id),3);		
		$ret .= $this->addLine(sprintf('%s = new GGeoXml("%s", cb_geo_%s);',$kmlname ,$url, $this->map_id),3);		
		$ret .= $this->addLine('}',2);
			
		//Running
		$ret .= $this->addLine('if (GBrowserIsCompatible()) {',2);
		$ret .= $this->addLine(sprintf('setTimeout(load_%s,100);', $this->map_id),3);
		$ret .= $this->addLine('} else {',2);
		$ret .= $this->addLine('document.write("Javascript must be enabled in order to use Google Maps.");',3);
		$ret .= $this->addLine('}',2);
		$ret .= $this->addLine('// -->',1);
		$ret .= $this->addLine('</script>');
		return $ret;		
	}
	
	function getContentElement() {
		$mapname = $this->map_id;
		$ret .= $this->addLine(sprintf('<div id="%s" style="width: %s; height: %s;"></div>',$this->map_id, $this->width, $this->height));
		$ret .= $this->addLine('<script type="text/javascript">');
		$ret .= $this->addLine('<!--',1);
		$ret .= $this->addLine(sprintf('var %s = null;',$mapname),2);
		
		//Workaraound for Showing other MapTypes than MAP
		$ret .= $this->addLine(sprintf('var smt_%s = function() {', $this->map_id),2);
		$ret .= $this->addLine(sprintf('%s.setMapType(%s);',$mapname,$this->map_type),3);
		$ret .= $this->addLine('}',2);
		
		//Loading		
		$ret .= $this->addLine(sprintf('function load_%s() {', $this->map_id),2);		
		$ret .= $this->addLine(sprintf('%s = new GMap2(document.getElementById("%s"));',$mapname,$this->map_id),3);
		$ret .= $this->addLine(sprintf('var zoom = %s.getBoundsZoomLevel(new GLatLngBounds(new GLatLng(%s,%s),new GLatLng(%s,%s)));',$mapname,$this->min_lat,$this->min_lon,$this->max_lat,$this->max_lon),3);	
		$ret .= $this->addLine(sprintf('%s.setCenter(new GLatLng(%s,%s), zoom);',$mapname, $this->center_lat,$this->center_lon),3);											
		if (strlen($this->panzoomcontrol)>0) {
		 $ret .= $this->addLine(sprintf('%s.addControl(new %s());',$mapname,$this->panzoomcontrol),3);
		}
		if (strlen($this->overviewmap)>0) {
		 $ret .= $this->addLine(sprintf('%s.addControl(new %s());',$mapname,$this->overviewmap),3);
		}		
		if (strlen($this->scalecontrol)>0) {
		 $ret .= $this->addLine(sprintf('%s.addControl(new %s());',$mapname,$this->scalecontrol),3);
		}				
		if (strlen($this->maptypecontrol)>0) {
		 $ret .= $this->addLine(sprintf('%s.addControl(new %s());',$mapname,$this->maptypecontrol),3);
		}																
		$markerct = 0;
		foreach($this->markers as $marker) {
		    $ret .= $this->addLine(sprintf('var %s_marker%s = new GMarker(new GLatLng(%s,%s));',$mapname, $markerct, $marker["lat"], $marker["lon"]),3);			
			$ret .= $this->addLine(sprintf('%s.addOverlay(%s_marker%s);',$mapname, $mapname,$markerct),3);								
			$ret .= $this->addLine(sprintf('%s_marker%s.bindInfoWindowHtml("%s");', $mapname, $markerct, $marker["html"]),3);
			$markerct++;
		}		
		foreach($this->polylines as $polyline) {
			$lastlat = 0;
			$lastlon = 0;
			$encpts = "";
			$enclev = "";
			$ct = 0;
			foreach($polyline["points"] as $point) {
				$lat = intval($point["lat"]*1e5);
				$lon = intval($point["lon"]*1e5);			
				$encpts .= $this->getEncoding($lat - $lastlat).$this->getEncoding($lon - $lastlon);
				$enclev .= "B";	
				$lastlat = $lat;
				$lastlon = $lon;
				$ct++;	
				if ($ct>=100) {
					$ret .= $this->addLine(sprintf('%s.addOverlay(new GPolyline.fromEncoded({color: "%s", weight: %s, opacity: %s, points: "%s", levels: "%s", zoomFactor: %s, numLevels: %s}));',$mapname,$polyline["color"], $polyline["weight"], $polyline["opacity"]/100,$encpts, $enclev, 32, 4),3);
					$lastlat = 0;
					$lastlon = 0;
					$encpts = "";
					$enclev = "";
					$ct = 1;
					$lat = intval($point["lat"]*1e5);
					$lon = intval($point["lon"]*1e5);			
					$encpts .= $this->getEncoding($lat - $lastlat).$this->getEncoding($lon - $lastlon);
					$enclev .= "B";	
					$lastlat = $lat;
					$lastlon = $lon;					
				}
			}
			$ret .= $this->addLine(sprintf('%s.addOverlay(new GPolyline.fromEncoded({color: "%s", weight: %s, opacity: %s, points: "%s", levels: "%s", zoomFactor: %s, numLevels: %s}));',$mapname,$polyline["color"], $polyline["weight"], $polyline["opacity"]/100,$encpts, $enclev, 32, 4),3);			
		}
		$ret .= $this->addLine(sprintf('setTimeout(smt_%s, 100);', $mapname, $this->map_id),3);
		$ret .= $this->addLine('}',2);
		
		//Running
		$ret .= $this->addLine('if (GBrowserIsCompatible()) {',2);
		$ret .= $this->addLine(sprintf('setTimeout(load_%s,100);', $this->map_id),3);
		$ret .= $this->addLine('} else {',2);
		$ret .= $this->addLine('document.write("Javascript must be enabled in order to use Google Maps.");',3);
		$ret .= $this->addLine('}',2);
		$ret .= $this->addLine('// -->',1);
		$ret .= $this->addLine('</script>');
		return $ret;		
	}
	
	function getEncoding($value) {
		$shifted = $value << 1;
		if ($value>0) {
		   $signing = $shifted;
		} else {
		   $signing = ~$shifted;
		}
		$bin = decbin($signing);
		$bin = str_pad($bin,ceil(strlen($bin)/5)*5,"0",STR_PAD_LEFT);
		$j=0;
		for ($i=strlen($bin)-1; $i>=0; $i=$i-5) {
		   $arr1[$j] = substr($bin,$i-4,5);
		   $j++;     
		}
		for ($i=0; $i<count($arr1); $i++) {
		   if ($i == count($arr1) -1) {
		      $arr2[$i] = "0".$arr1[$i];
		   } else {
		      $arr2[$i] = "1".$arr1[$i];
		   }
		}
		for ($i=0; $i<count($arr2); $i++) {
		   $arr3[$i] = 63 + bindec($arr2[$i]);
		}
		$ret = "";
		for ($i=0; $i<count($arr3); $i++) {
		   $ret.=chr($arr3[$i]);
		}
		return str_replace("\\","\\\\",$ret);
	}
		
	function addLine($text='', $indent = 0) {
		$ret = "";
		for ($i=0;$i<$indent;$i++) {
			$ret .= "   ";
		}
		return $ret.$text."\n";
	}
	
}


?>